@@ -5,7 +5,7 @@ from typing import Type
 from typing import TypeVar
 
 
-__version__ = "0.1.0"
+__version__ = "0.4.2"
 
 
 T = TypeVar("T")
@@ -35,6 +35,6 @@ def test(description: str) -> Callable[..., T]:
 def raises(
     expected_exception: Type[BaseException], **kwargs
 ) -> "RaisesContext[BaseException]":
-    from treat.pytest._augmentations import RaisesContext
+    import pytest
 
-    return RaisesContext(expected_exception, **kwargs)
+    return pytest.raises(expected_exception, **kwargs)
