@@ -1,5 +1,5 @@
+from typing import Any
 from typing import Dict
-from typing import Type
 
 from treat.mock.expectation import Expectation
 from treat.mock.expectation import ExpectationKind
@@ -8,15 +8,15 @@ from treat.utils._compat import ReversableDict
 
 
 class Mock:
-    def __init__(self, mocked: Type) -> None:
-        self._mocked: Type = mocked
+    def __init__(self, mocked: Any) -> None:
+        self._mocked: Any = mocked
         self._expectation_directors: Dict[str, ExpectationDirector] = ReversableDict()
 
     @property
-    def mocked(self) -> Type:
+    def mocked(self) -> Any:
         return self._mocked
 
-    def expects(self, name: str) -> Expectation:
+    def should_receive(self, name: str) -> Expectation:
         if name not in self._expectation_directors:
             director = ExpectationDirector(name, self)
             director.setup()
